==> haskell-syb-0.7.2.4-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 syb
version:              0.7.2.4
visibility:           public
id:                   syb-0.7.2.4-KjjXDkbXsb76a0JbGOnZpL
key:                  syb-0.7.2.4-KjjXDkbXsb76a0JbGOnZpL
license:              BSD-3-Clause
maintainer:           Sergey Vinokurov <serg.foo@gmail.com>
author:               Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability:            provisional
homepage:             https://github.com/dreixel/syb
synopsis:             Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.

category:             Generics
abi:                  28a711010eef36e2301cc684ec871ea4
exposed:              True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins

import-dirs:          /usr/lib/ghc-9.2.8/site-local/syb-0.7.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/syb-0.7.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-syb
hs-libraries:         HSsyb-0.7.2.4-KjjXDkbXsb76a0JbGOnZpL
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html:         /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-syb-0.7.2.4-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 syb
version:              0.7.2.4
visibility:           public
id:                   syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V
key:                  syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V
license:              BSD-3-Clause
maintainer:           Sergey Vinokurov <serg.foo@gmail.com>
author:               Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability:            provisional
homepage:             https://github.com/dreixel/syb
synopsis:             Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.

category:             Generics
abi:                  0d8162ee55428523c8bb49389e765ba1
exposed:              True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins

import-dirs:          /usr/lib/ghc-9.2.8/site-local/syb-0.7.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/syb-0.7.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-syb
hs-libraries:         HSsyb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html:         /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
